summaryrefslogtreecommitdiffstats
path: root/kenolaba/Ball.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
commitc0f375feba0103bed2bac1b1f05e76e9ae28fa89 (patch)
tree9c30a9097d650343df41d867f0e008769529eb08 /kenolaba/Ball.cpp
parent0e2b76239f354a9eead0b4e37d86d390ec57ffa9 (diff)
downloadtdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.tar.gz
tdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kenolaba/Ball.cpp')
-rw-r--r--kenolaba/Ball.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kenolaba/Ball.cpp b/kenolaba/Ball.cpp
index 39448305..392a61c5 100644
--- a/kenolaba/Ball.cpp
+++ b/kenolaba/Ball.cpp
@@ -21,14 +21,14 @@ void Ball::setSize(int x, int y)
sizeX = x;
sizeY = y;
- tqinvalidate();
+ invalidate();
}
-void Ball::tqinvalidate()
+void Ball::invalidate()
{
Ball *b;
/* tqinvalidate all Balls... */
for(b=first;b!=0;b=b->next)
b->pm.resize(0,0);
}
@@ -43,7 +43,7 @@ void Ball::setLight(int x, int y, int z, const TQColor& c)
lightColor = c;
- tqinvalidate();
+ invalidate();
}
@@ -52,7 +52,7 @@ void Ball::setTexture(double c, double d)
rippleCount = c;
rippleDepth = d;
- tqinvalidate();
+ invalidate();
}
@@ -309,7 +309,7 @@ void BallWidget::resizeEvent(TQResizeEvent *)
realSize = (w>h) ? h:w;
Ball::setSize( realSize/ballFraction, realSize/ballFraction );
- tqrepaint();
+ repaint();
}
void BallWidget::paintEvent(TQPaintEvent *)
@@ -414,7 +414,7 @@ void BallWidget::animate()
timer->start(1000/freq,true);
}
- // tqrepaint( false );
+ // repaint( false );
}
@@ -21,14 +21,14 @@ void Ball::setSize(int x, int y)
{
Ball *b;
- /* tqinvalidate all Balls... */
+ /* invalidate all Balls... */
for(b=first;b!=0;b=b->next)
b->pm.resize(0,0);